==> sns-1.32.0-sources.jar: software/amazon/awscdk/services/sns/ITopicSubscription.java <==
package software.amazon.awscdk.services.sns;

/**
 * Topic subscription.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.1.0 (build df55f5e)", date = "2020-04-07T12:30:30.498Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.sns.$Module.class, fqn = "@aws-cdk/aws-sns.ITopicSubscription")
@software.amazon.jsii.Jsii.Proxy(ITopicSubscription.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ITopicSubscription extends software.amazon.jsii.JsiiSerializable {

    /**
     * @param topic This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.sns.TopicSubscriptionConfig bind(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.sns.ITopic topic);

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.sns.ITopicSubscription {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * @param topic This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.sns.TopicSubscriptionConfig bind(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.sns.ITopic topic) {
            return this.jsiiCall("bind", software.amazon.awscdk.services.sns.TopicSubscriptionConfig.class, new Object[] { java.util.Objects.requireNonNull(topic, "topic is required") });
        }
    }
}

==> sns-1.60.0-sources.jar: software/amazon/awscdk/services/sns/ITopicSubscription.java <==
package software.amazon.awscdk.services.sns;

/**
 * Topic subscription.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:13.460Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.sns.$Module.class, fqn = "@aws-cdk/aws-sns.ITopicSubscription")
@software.amazon.jsii.Jsii.Proxy(ITopicSubscription.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ITopicSubscription extends software.amazon.jsii.JsiiSerializable {

    /**
     * Returns a configuration used to subscribe to an SNS topic.
     * <p>
     * @param topic topic for which subscription will be configured. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.sns.TopicSubscriptionConfig bind(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.sns.ITopic topic);

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.sns.ITopicSubscription {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * Returns a configuration used to subscribe to an SNS topic.
         * <p>
         * @param topic topic for which subscription will be configured. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.sns.TopicSubscriptionConfig bind(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.sns.ITopic topic) {
            return this.jsiiCall("bind", software.amazon.awscdk.services.sns.TopicSubscriptionConfig.class, new Object[] { java.util.Objects.requireNonNull(topic, "topic is required") });
        }
    }
}
